==> deepin-screen-recorder_2.7.3.orig.tar.xz: deepin-screen-recorder-2.7.3/src/countdown_tooltip.h <==
/* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
 * -*- coding: utf-8 -*-
 *
 * Copyright (C) 2011 ~ 2017 Deepin, Inc.
 *               2011 ~ 2017 Wang Yong
 *
 * Author:     Wang Yong <wangyong@deepin.com>
 * Maintainer: Wang Yong <wangyong@deepin.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef COUNTDOWNTOOLTIP_H
#define COUNTDOWNTOOLTIP_H

#include <QWidget>
#include <QTimer>

class CountdownTooltip : public QWidget 
{
    Q_OBJECT
    
    static const int NUMBER_PADDING_Y;
    
public:
    CountdownTooltip(QWidget *parent = 0);
    void start();
                         
signals:
    void finished();

public slots:
    void update();
    
protected:
    void paintEvent(QPaintEvent *event);
    
private:
    QPixmap countdown1Img;
    QPixmap countdown2Img;
    QPixmap countdown3Img;
    
    int showCountdownCounter;
    
    QTimer* showCountdownTimer;
    
    QString text;
};

#endif // COUNTDOWNTOOLTIP_H

==> deepin-screen-recorder_5.8.1.orig.tar.xz: deepin-screen-recorder-5.8.1/src/countdown_tooltip.h <==
/* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
 * -*- coding: utf-8 -*-
 *
 * Copyright (C) 2011 ~ 2018 Deepin, Inc.
 *               2011 ~ 2018 Wang Yong
 *
 * Author:     Wang Yong <wangyong@deepin.com>
 * Maintainer: Wang Yong <wangyong@deepin.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef COUNTDOWNTOOLTIP_H
#define COUNTDOWNTOOLTIP_H

#include <DWidget>
#include <QTimer>

DWIDGET_USE_NAMESPACE

class CountdownTooltip : public DWidget
{
    Q_OBJECT

    static const int NUMBER_PADDING_Y;

public:
    explicit CountdownTooltip(DWidget *parent = 0);
    void start();

signals:
    void finished();

public slots:
    void update();

protected:
    void paintEvent(QPaintEvent *event);

private:
    QPixmap countdown1Img;
    QPixmap countdown2Img;
    QPixmap countdown3Img;

    int showCountdownCounter;

    QTimer *showCountdownTimer;

    QString text;
};

#endif // COUNTDOWNTOOLTIP_H
